@@ -9,10 +9,9 @@ use File::Find qw/ find /;
 use Mojo::Loader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = 0.021;
+our $VERSION = '0.03';
 
 my $MODEL_DIR  = 'Model'; # directory in poject for Model-modules
-my $BASE_MODEL = 'Base';  # default name for Base model
 my $CREATE_DIR = 1;
 my $USE_BASE_MODEL = 1;
 my %MODULES = ();
@@ -20,7 +19,7 @@ my %MODULES = ();
 sub register {
     my ( $self, $app, $conf ) = @_;
 
-    my $app_name      = ref $app;
+    my $app_name      = ref $app; # name of calling app
     my $path_to_model = $app->home->lib_dir . '/' . $app_name . '/' . $MODEL_DIR;
     my $dir_exists    = $self->check_model_dir( $path_to_model );
     my $create_dir    = $conf->{create_dir} || $CREATE_DIR;
@@ -28,9 +27,6 @@ sub register {
     if ( exists $conf->{use_base_model} && $conf->{use_base_model} == 0 ) {
         $USE_BASE_MODEL = 0;
     }
-    if ( $USE_BASE_MODEL && $conf->{base_model} ) {
-        $BASE_MODEL = $conf->{base_model};
-    }
 
     if ( ! $dir_exists && ! $create_dir ) {
         warn "Directory $app_name/$MODEL_DIR does not exist";
@@ -40,7 +36,6 @@ sub register {
         mkdir $path_to_model or croak "Could not create directory $path_to_model : $!";
     }
 
-    $self->generate_base_model( $path_to_model, $app_name ) if $USE_BASE_MODEL;
     $self->load_models( $path_to_model, $app_name, $app );
 
     $app->helper(
@@ -62,6 +57,7 @@ sub check_model_dir {
     return;
 }
 
+# recursive search and download modules with models
 sub load_models {
     my ( $self, $path_to_model, $app_name, $app ) = @_;
 
@@ -79,10 +75,8 @@ sub load_models {
         ( $path_to_model )
     );
 
-    my $base_model = '';
-
     if ( $USE_BASE_MODEL ) {
-        $base_model  = $model_path . '::' . $BASE_MODEL;
+        my $base_model = 'Mojolicious::BModel::Base';
         my $base_load_err = Mojo::Loader->load( $base_model );
         croak "Loading base model $base_model failed: $base_load_err" if ref $base_load_err;
         {
@@ -94,7 +88,7 @@ sub load_models {
 
     for my $dir ( @model_dirs ) {
         my $model_packages = Mojo::Loader->search( $dir );
-        for my $pm ( grep { $_ ne $base_model } @{ $model_packages } ) {
+        for my $pm ( @{ $model_packages } ) {
             my $load_err = Mojo::Loader->load( $pm );
             croak "Loading '$pm' failed: $load_err" if ref $load_err;
             my ( $basename ) = $pm =~ /$model_path\::(.*)/;
@@ -105,26 +99,6 @@ sub load_models {
     return 1;
 }
 
-sub generate_base_model {
-    my ( $self, $path_to_model, $app_name ) = @_;
-
-    my $base_model = $path_to_model . '/' . $BASE_MODEL . '.pm';
-    return if -e $base_model;
-
-    system( "touch $base_model" );
-
-    my $base_model_name  = $app_name . '::' . $MODEL_DIR . '::' . $BASE_MODEL;
-    my $module_data = "package $base_model_name;\n\nuse strict;\nuse warnings;\n\n";
-    $module_data .= "use Mojo::Base -base;\n\n";
-    $module_data .= "has config => sub { my \$self = shift; return \$self->app->config };\n\n1;\n";
-
-    open( BASE_MODEL, '>', $base_model ) or croak "Can't open $base_model: $!";
-    print BASE_MODEL $module_data;
-    close( BASE_MODEL );
-
-    return 1;
-}
-
 1;
 
 __END__
@@ -147,7 +121,6 @@ Mojolicious::Plugin::BModel - Catalyst-like models in Mojolicious
             {
                 use_base_model => 1,
                 create_dir     => 1,
-                base_model     => 'Base',
             }
         );
     }
@@ -160,20 +133,127 @@ Mojolicious::Plugin::BModel - Catalyst-like models in Mojolicious
     }
 
     # in <your_app>/lib/Model/MyModel.pm:
+
+    use Mojo::Base 'Mojolicious::BModel::Base';
+
     sub get_conf_data {
         my ( $self, $field ) = @_;
         
         # as example
-        return $self->app->config->{field};
+        return $self->config->{field};
     }
 
 =head1 DESCRIPTION
 
 Mojolicious::Plugin::BModel adds the ability to work with models in Catalyst
 
+=head2 Options
+
+=over
+
+=item B<use_base_model>
+
+    A flag that specifies the use of the basic model.
+    0 - do not use, 1 - use. Enabled by default
+
+=item B<create_dir>
+
+    A flag that determines automatically create the folder '<yourapp>/lib/Model'
+    if it does not exist. 0 - do not create, 1 - create. Enabled by default
+
+=back
+
+=cut
+
+=head1 EXAMPLE
+
+    # the example of a new application:
+    % cpan install Mojolicious::Plugin::BModel
+    % mojo generate app MyApp
+    % cd my_app/
+    % vim lib/MyApp.pm
+
+    # edit file:
+    package MyApp;
+
+    use Mojo::Base 'Mojolicious';
+
+    sub startup {
+        my $self = shift;
+
+        $self->config->{testkey} = 'MyTestValue';
+
+        $self->plugin( 'BModel' ); # used the default options
+
+        my $r = $self->routes;
+        $r->get('/')->to( 'root#index' );
+    }
+
+    1;
+
+    # end of edit file
+
+    # create a new controller
+
+    % touch lib/Controller/Root.pm
+    % vim lib/Controller/Root.pm
+
+    # edit file
+
+    package MyApp::Controller::Root;
+
+    use Mojo::Base 'Mojolicious::Controller';
+
+    sub index {
+        my $self = shift;
+
+        my $testkey_val = $self->model('MyModel')->get_conf_key('testkey');
+        $self->render( text => 'Value: ' . $testkey_val );
+    }
+
+    1;
+
+    # end of edit file
+
+    # When you connect, the plugin will check if the folder "lib/Model".
+    # If the folder does not exist, create it.
+    # If the 'use_base_model' is set to true will be loaded
+    # module "Mojolicious::BModel::Base" with the base model.
+    # Method 'app' base model will contain a link to your application.
+    # Method 'config' base model will contain a link to config of yor application.
+
+    # create a new model
+    % touch lib/MyApp/Model/MyModel.pm
+    % vim lib/MyApp/Model/MyModel.pm
+
+    # edit file
+
+    package MyApp::Model::MyModel;
+
+    use strict;
+    use warnings;
+
+    use Mojo::Base 'Mojolicious::BModel::Base';
+
+    sub get_conf_key {
+        my ( $self, $key ) = @_;
+
+        return $self->config->{ $key } || '';
+    }
+
+    1;
+    
+    # end of edit file
+
+    % morbo -v script/my_app
+
+    # Open in your browser address http://127.0.0.1:3000 and
+    # you'll see text 'Value: MyTestValue'
+
+
 =head1 LICENSE
 
-Copyright (C) Alexander Ruzhnikov.
+Copyright (C) 2015 Alexander Ruzhnikov.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
